---
title: <span class="badge builder"></span> ScalarDimensionConfig
---
# <span class="badge builder"></span> ScalarDimensionConfig

## Constructor

```python
ScalarDimensionConfig()
```
## Methods

### <span class="badge object-method"></span> build

Builds the object.

```python
def build() -> common.ScalarDimensionConfig
```

### <span class="badge object-method"></span> field

fixed: T -- will be added by each element

```python
def field(field: str) -> typing.Self
```

### <span class="badge object-method"></span> fixed

```python
def fixed(fixed: float) -> typing.Self
```

### <span class="badge object-method"></span> max_val

```python
def max_val(max_val: float) -> typing.Self
```

### <span class="badge object-method"></span> min_val

```python
def min_val(min_val: float) -> typing.Self
```

### <span class="badge object-method"></span> mode

```python
def mode(mode: common.ScalarDimensionMode) -> typing.Self
```

## See also

 * <span class="badge object-type-class"></span> [ScalarDimensionConfig](./object-ScalarDimensionConfig.md)
